
# Pratik_model
- The best thing about this package is that you don’t have to train and predict every classification or regression algorithm to check performance. This package directly gives you output performance on 13 different algorithms.

# How to use it 
 Check Pratik_Model_Package.ipynb file on Github for referance.

# Pratik_model for Classification: 
 will check the performance on this Classification models:
- Passive Aggressive Classifier
- Decision Tree Classifier
- Random Forest Classifier
- Extra Trees Classifier
- Logistic Regression
- Ridge Classifier
- K Neighbors Classifier
- Support Vector Classification
- Naive Bayes Classifier
- LGBM Classifier
- CatBoost Classifier
- XGB Classifier

And for classification problems Pratik_model can give the output of:
- Accuracy Score.
- Classification Report
- Confusion Matrix
- Cross validation (Cross validation score)
- Mean Absolute Error
- Mean Squared Error
- Overfitting (will give accuracy of training and testing data.)
- Precision Score
- Recall Score

# Pratik_model for Regression: 
Similarly, will check performance on this Regression model:
- Passive Aggressive Regressor
- Gradient Boosting Regressor
- Decision Tree Regressor
- Random Forest Regressor
- Extra Trees Regressor
- Lasso Regression
- K Neighbors Regressor
- Linear Regression
- Support Vector Regression
- LGBM Regressor
- CatBoost Regressor
- XGB Regressor

And for Regression problem Pratik_model
 can give an output of:
- R2 Score.
- Cross validation (Cross validation score)
- Mean Absolute Error
- Mean Squared Error
- Overfitting (will give accuracy of training and testing data.)




# First Release

0.0.2 (29/3/2022)

# Thank You!!.
